"use client";
import { AppContext } from "@/providers/AppbarProvider";
import {
  Button,
  Collapse,
  Divider,
  Drawer,
  List,
  ListItemButton,
  ListItemText,
  Stack,
} from "@mui/material";
import { use, useState } from "react";
import MenuButton from "./MenuButton";
import UserButton from "../buttons/UserButton";
import Link from "next/link";

import { ChevronLeft, ExpandLess, ExpandMore } from "@mui/icons-material";
import { useRouter } from "next/navigation";

const ListBaseButton = ({ list, closeSideBar }) => {
  const router = useRouter();

  const [showLinks, setShowLinks] = useState(false);
  if (!list || !list.active) return null;
  return (
    <Stack className="w-full" gap={1}>
      <>
        {list.hasLink && (!list.lists || list.lists.length <= 0) && (
          <ListItemButton
            sx={{ borderRadius: "6px" }}
            onClick={() => {
              setShowLinks((prev) => !prev);
              router.push(list.link);
            }}
          >
            <ListItemText
              slotProps={{ primary: { fontWeight: "bold" } }}
              primary={list.title}
            />
            <ChevronLeft color="primary" />
          </ListItemButton>
        )}
        {((list.hasLink && list.lists && list.lists.length > 0) ||
          !list.hasLink) && (
          <ListItemButton
            sx={{ borderRadius: "6px" }}
            onClick={() => {
              setShowLinks((prev) => !prev);
            }}
          >
            <ListItemText
              slotProps={{ primary: { fontWeight: "bold" } }}
              primary={list.title}
            />
            {showLinks ? (
              <ExpandLess color="primary" />
            ) : (
              <ExpandMore color="primary" />
            )}
          </ListItemButton>
        )}
      </>

      {list && list.lists && list.lists.length > 0 && (
        <Collapse in={showLinks} timeout="auto" unmountOnExit>
          <List component="div" disablePadding>
            {list.hasLink && list.lists.length > 0 && (
              <ListItemButton
                sx={{ pl: 1 }}
                onClick={() => {
                  router.push(list.link);
                  setShowLinks(false);
                  closeSideBar();
                }}
              >
                <ListItemText primary={list.title} />
                <ChevronLeft color="secondary"/>
              </ListItemButton>
            )}
            {list.lists.map((link, linkIndex) => (
              <ListItemButton
                sx={{ pl: 1 }}
                key={linkIndex}
                onClick={() => {
                  router.push(link.link);
                  setShowLinks(false);
                  closeSideBar();
                }}
              >
                <ListItemText primary={link.title} />
                <ChevronLeft color="secondary"/>
              </ListItemButton>
            ))}
          </List>
        </Collapse>
      )}
    </Stack>
  );
};

const AppDrawer = ({ lists }) => {
  const { openMainSideBar, handleToggleMainSideBar } = use(AppContext);

  return (
    <Drawer open={openMainSideBar} onClose={handleToggleMainSideBar}>
      <div className="w-[270px] h-full  flex flex-col gap-3 p-3">
        <div className="w-full flex items-center justify-between ">
          <MenuButton />
          <UserButton />
        </div>
        <Divider />
        <Link href={"/products"} className="w-full">
          <Button fullWidth variant="contained" sx={{ fontWeight: "bold" }}>
            خرید بسته طلایی
          </Button>
        </Link>
        <div className="w-full flex flex-col gap-3">
          {lists.map((list, listIndex) => (
            <ListBaseButton
              list={list}
              key={listIndex}
              closeSideBar={handleToggleMainSideBar}
            />
          ))}
        </div>
      </div>
    </Drawer>
  );
};

export default AppDrawer;
